# NC State Authentication Package

This package is meant to make authenticating users for PHP web applications at NC State
easier to manage.

## Goals

* Standardize authentication interface for several on-campus providers.
* Provide extensible authentication framework to allow for custom integrations.

## Install

Via Composer

``` json
{
    "repositories": [
        {
            "type": "vcs",
            "url": "git@github.ncsu.edu:ncstate-contrib/auth.git"
        }
    ],
    "require": {
        "ncsu/auth": "~1.0"
    }
}
```

## Requirements

The following versions of PHP are supported by this version.

* PHP 5.3
* PHP 5.4
* PHP 5.5

## Documentation

Will be dropping some usage documentation here! I promise.

``` php
// Example of WRAP Authentication

<?php

require_once('../vendor/autoload.php');

use NCSU\Auth\Adapter\WrapAuthAdapter;
use NCSU\Auth\AuthService;
use NCSU\Auth\Http\Request;

$request = Request::createFromGlobals();

$wrapAuthAdapter = new WrapAuthAdapter($request);
$service = new AuthService($wrapAuthAdapter);

$result = $service->authenticate();

if ($result->isValid()) {
    echo sprintf("Your authentication request as %s was successful!", $result->getIdentity());
} else {
    echo "Failed to authenticate!";
}
```

## Testing

``` bash
$ phpunit
```

## Contributing

Contributions are **welcome** and will be fully **credited**.

We accept contributions via Pull Requests on [Github](https://github.ncsu.edu/ncstate-contrib/auth).

## Pull Requests

- **[PSR-2 Coding Standard](https://github.com/php-fig/fig-standards/blob/master/accepted/PSR-2-coding-style-guide.md)** - The easiest way to apply the conventions is to install [PHP Code Sniffer](http://pear.php.net/package/PHP_CodeSniffer).

- **Add tests!** - Your patch won't be accepted if it doesn't have tests.

- **Document any change in behaviour** - Make sure the README and any other relevant documentation are kept up-to-date.

- **Consider our release cycle** - We try to follow semver. Randomly breaking public APIs is not an option.

- **Create topic branches** - Don't ask us to pull from your master branch.

- **One pull request per feature** - If you want to do more than one thing, send multiple pull requests.

- **Send coherent history** - Make sure each individual commit in your pull request is meaningful. If you had to make multiple intermediate commits while developing, please squash them before submitting.

## Running Tests

``` bash
$ phpunit
```

**Happy coding**!

## License

The MIT License (MIT). Please see [License File](./LICENSE) for more information.
