<?php

namespace NCSU\Auth\Adapter;

use NCSU\Auth\Adapter\ShibAuthAdapter;
use NCSU\Auth\Http\Request;

/**
 * @runTestsInSeparateProcesses
 * @backupGlobals enabled
 */
class ShibAuthAdapterTest extends \PHPUnit_Framework_TestCase
{
    /** @test */
    public function it_should_return_valid_auth_result_after_user_has_authenticated()
    {
        $this->beShibbolethUser('cacard');

        $adapter = new ShibAuthAdapter(Request::createFromGlobals());
        $result = $adapter->authenticate();

        $this->assertInstanceOf('\NCSU\Auth\AuthResult', $result);
        $this->assertTrue($result->isValid());
        $this->assertEquals('cacard', $result->getIdentity());
    }

    /** @test */
    public function it_should_return_invalid_auth_result_when_user_is_not_authenticated()
    {
        $this->fakeServer();
        $this->beShibbolethUser('');

        $adapter = new ShibAuthAdapter(Request::createFromGlobals());
        $result = $adapter->authenticate();

        $this->assertFalse($result->isValid());
    }

    /** @test */
    public function it_should_return_true_when_the_user_is_authenticated()
    {
        $this->beShibbolethUser('cacard');

        $adapter = new ShibAuthAdapter(Request::createFromGlobals());

        $this->assertTrue($adapter->isAuthenticated());
    }

    /** @test */
    public function it_should_return_false_when_the_user_is_not_authenticated()
    {
        $this->beShibbolethUser('');

        $adapter = new ShibAuthAdapter(Request::createFromGlobals());

        $this->assertFalse($adapter->isAuthenticated());
    }

    private function beShibbolethUser($userId)
    {
        $_SERVER['Shib-Session-ID'] = (($userId !== '') ? 'foo' : null);
        $_SERVER['SHIB_UID'] = $userId;
    }

    private function fakeServer()
    {
        $_SERVER['SERVER_NAME'] = 'foo';
        $_SERVER['REQUEST_URI'] = 'foo';
    }
}
